Publications 
============

Permanent Link to Software
--------------------------

* `DOI:10.11578/dc.20240115.1 <https://doi.org/10.11578/dc.20240115.1>`_


Journals and Conference Papers
------------------------------

Currently we don't have any articles to show here.
If you have an interesting paper that uses MontePy,
open an issue and we may add it here.
